@@ -4,7 +4,8 @@ setClass(
   representation(
     name = 'character',
     center = 'function',
-    trajectoryClusterIndices = 'integer'
+    trajectoryClusterIndices = 'integer',
+    converged = 'ANY'
   ),
   contains = 'lcApproxModel'
 )
@@ -23,6 +24,7 @@ setClass(
 #' @param clusterNames The names of the clusters, or a function with input `n` outputting a `character vector` of names.
 #' If unspecified, the names are determined from the `trajectoryAssignments` argument.
 #' @param method Optional `lcMethod` object that was used for fitting this model to the data.
+#' @param converged Set the converged state.
 #' @param model An optional object to attach to the `lcModelPartition` object, representing the internal model that was used for obtaining the partition.
 #' @param envir The `environment` associated with the model. Used for evaluating the assigned `data` object by [model.data.lcModel].
 #' @examples
@@ -50,6 +52,7 @@ lcModelPartition = function(
   name = 'part',
   center = meanNA,
   method = NULL,
+  converged = TRUE,
   model = NULL,
   envir = parent.frame()
 ) {
@@ -169,7 +172,8 @@ lcModelPartition = function(
     id = id,
     time = time,
     response = response,
-    estimationTime = 0
+    estimationTime = 0,
+    converged = converged
   )
 
   if (!is.null(method)) {
@@ -255,7 +259,11 @@ setMethod('clusterTrajectories', 'lcModelPartition',
 #. converged ####
 #' @rdname interface-custom
 setMethod('converged', 'lcModelPartition', function(object, ...) {
-  TRUE
+  if (methods::.hasSlot(object, 'converged')) {
+    object@converged
+  } else {
+    TRUE
+  }
 })
 
 
